@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 FreeIPMI Core Team
+ * Copyright (C) 2003-2014 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <string.h>
 #endif /* STDC_HEADERS */
 #include <errno.h>
+#include <assert.h>
 
 #include "freeipmi/api/ipmi-serial-modem-cmds-api.h"
 #include "freeipmi/cmds/ipmi-serial-modem-cmds.h"
@@ -423,6 +424,8 @@ _ipmi_cmd_get_serial_modem_configuration_parameters_common (ipmi_ctx_t ctx,
   fiid_obj_t obj_cmd_rq = NULL;
   int rv = -1;
 
+  assert (tmpl_cmd_rs_expected);
+
   if (!ctx || ctx->magic != IPMI_CTX_MAGIC)
     {
       ERR_TRACE (ipmi_ctx_errormsg (ctx), ipmi_ctx_errnum (ctx));
