@@ -145,6 +145,10 @@ extern "C" {
 
 #define IPMI_INTEL_PRODUCT_ID_WINDMILL 2818
 
+#define IPMI_INTEL_PRODUCT_ID_S2600KP  111
+#define IPMI_INTEL_PRODUCT_ID_S2600WT2 112
+#define IPMI_INTEL_PRODUCT_ID_S2600WTT 112
+
 /* 
  * Intel derived
  */
