@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 FreeIPMI Core Team
+ * Copyright (C) 2003-2014 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,15 @@ int sel_string_output_intel_sensor_name (ipmi_sel_ctx_t ctx,
 					 struct ipmi_sel_system_event_record_data *system_event_record_data,
 					 int *oem_rv);
 
+int sel_string_output_intel_event_data1_class_sensor_specific_discrete (ipmi_sel_ctx_t ctx,
+									struct ipmi_sel_entry *sel_entry,
+									uint8_t sel_record_type,
+									char *tmpbuf,
+									unsigned int tmpbuflen,
+									unsigned int flags,
+									unsigned int *wlen,
+									struct ipmi_sel_system_event_record_data *system_event_record_data);
+
 int sel_string_output_intel_event_data1_class_oem (ipmi_sel_ctx_t ctx,
 						   struct ipmi_sel_entry *sel_entry,
 						   uint8_t sel_record_type,
@@ -94,5 +103,14 @@ int sel_string_output_intel_event_data2_event_data3 (ipmi_sel_ctx_t ctx,
 						     unsigned int *wlen,
 						     struct ipmi_sel_system_event_record_data *system_event_record_data,
 						     int *oem_rv);
+ 
+int sel_string_output_intel_oem_record_data (ipmi_sel_ctx_t ctx,
+					     struct ipmi_sel_entry *sel_entry,
+					     uint8_t sel_record_type,
+					     char *buf,
+					     unsigned int buflen,
+					     unsigned int flags,
+					     unsigned int *wlen,
+					     int *oem_rv);
 
 #endif /* IPMI_SEL_STRING_INTEL_H */
